@@ -39,12 +39,12 @@ class Backend(BaseBackend):
         key, url = get_settings()
         try:
             temp_url = swiftclient.utils.generate_temp_url(
-                path='/v%s%s/%s/%s' % (SWIFT_BACKEND_VERSION, url.path, bucket_name, key_name),
+                path=f'/v{SWIFT_BACKEND_VERSION}{url.path}/{bucket_name}/{key_name}',
                 key=key,
                 method='PUT',
                 seconds=self.UPLOAD_URL_TIMEOUT
             )
-            return '%s://%s%s' % (url.scheme, url.netloc, temp_url)
+            return f'{url.scheme}://{url.netloc}{temp_url}'
         except Exception as ex:
             logger.exception(
                 "An internal exception occurred while generating an upload URL."
@@ -56,12 +56,12 @@ class Backend(BaseBackend):
         key, url = get_settings()
         try:
             temp_url = swiftclient.utils.generate_temp_url(
-                path='/v%s%s/%s/%s' % (SWIFT_BACKEND_VERSION, url.path, bucket_name, key_name),
+                path=f'/v{SWIFT_BACKEND_VERSION}{url.path}/{bucket_name}/{key_name}',
                 key=key,
                 method='GET',
                 seconds=self.DOWNLOAD_URL_TIMEOUT
             )
-            download_url = '%s://%s%s' % (url.scheme, url.netloc, temp_url)
+            download_url = f'{url.scheme}://{url.netloc}{temp_url}'
             response = requests.get(download_url)
             return download_url if response.status_code == 200 else ""
         except Exception as ex:
@@ -75,11 +75,11 @@ class Backend(BaseBackend):
         key, url = get_settings()
         try:
             temp_url = swiftclient.utils.generate_temp_url(
-                path='%s/%s/%s' % (url.path, bucket_name, key_name),
+                path=f'{url.path}/{bucket_name}/{key_name}',
                 key=key,
                 method='DELETE',
                 seconds=self.DOWNLOAD_URL_TIMEOUT)
-            remove_url = '%s://%s%s' % (url.scheme, url.netloc, temp_url)
+            remove_url = f'{url.scheme}://{url.netloc}{temp_url}'
             response = requests.delete(remove_url)
             return response.status_code == 204
         except Exception as ex:
